@@ -8,6 +8,7 @@ import java.util.List;
 
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.tdtemplate.client.TdTemplateController;
+import org.gcube.portlets.user.tdtemplate.client.locale.SelectableSimpleComboBox;
 import org.gcube.portlets.user.tdtemplate.client.template.view.BaloonPanel;
 import org.gcube.portlets.user.tdtemplate.client.template.view.external.DialogCodelistResolver;
 import org.gcube.portlets.user.tdtemplate.shared.SPECIAL_CATEGORY_TYPE;
@@ -47,7 +48,7 @@ public class SetColumnTypeDialogManager {
 	
 	private SimpleComboBox<String> scbReferenceColumn = new SimpleComboBox<String>();
 	
-	private SimpleComboBox<String> scbLocales = new SimpleComboBox<String>();
+	private SelectableSimpleComboBox<String> scbLocales = new SelectableSimpleComboBox<String>();
 	
 	private SimpleComboBox<String> scbPeriodTypes = new SimpleComboBox<String>();
 	
@@ -179,13 +180,10 @@ public class SetColumnTypeDialogManager {
 		for (String locale : controller.getAllowedLocales())
 			ls.add(locale);
 
-		scbLocales = new SimpleComboBox<String>();
+		scbLocales = new SelectableSimpleComboBox<String>();
 		scbLocales.setFieldLabel("Locale *");
-		scbLocales.setTypeAhead(true);
-		scbLocales.setEditable(false);
 		scbLocales.setEmptyText(CHOOSE_LOCALE);
 		scbLocales.setToolTip("Locale");
-		scbLocales.setTriggerAction(TriggerAction.ALL);
 		
 		scbLocales.add(controller.getLocaleViewManager().getLocales());
 			
@@ -305,7 +303,7 @@ public class SetColumnTypeDialogManager {
 		public void handleEvent(BaseEvent be) {
 			if(scbCategory.getSimpleValue().compareToIgnoreCase(SPECIAL_CATEGORY_TYPE.DIMENSION.getLabel())==0){
 //				scbDataType.mask("Loading");
-				DialogCodelistResolver resolver = new DialogCodelistResolver(INSTANCE);
+				DialogCodelistResolver resolver = new DialogCodelistResolver(INSTANCE, controller);
 				resolver.show();
 			}else if(scbCategory.getSimpleValue().compareToIgnoreCase(SPECIAL_CATEGORY_TYPE.TIMEDIMENSION.getLabel())==0){
 //				DialogCodelistResolver resolver = new DialogCodelistResolver(INSTANCE);
